==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CalloutStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutStyleUpdatingEventArgsDescription } from "./CalloutStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutStyleUpdatingEventArgsDescriptionMetadata.c(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.j(CalloutStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.aa("CalloutStyleUpdatingEventArgs", () => new CalloutStyleUpdatingEventArgsDescription());
            a.z("CalloutStyleUpdatingEventArgs", CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutStyleUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutStyleUpdatingEventArgsDescriptionMetadata, 'CalloutStyleUpdatingEventArgsDescriptionMetadata');
    CalloutStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutStyleUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalloutStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutStyleUpdatingEventArgsDescription } from "./CalloutStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutStyleUpdatingEventArgsDescriptionMetadata.c(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("CalloutStyleUpdatingEventArgs", () => new CalloutStyleUpdatingEventArgsDescription());
            a.ab("CalloutStyleUpdatingEventArgs", CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutStyleUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutStyleUpdatingEventArgsDescriptionMetadata, 'CalloutStyleUpdatingEventArgsDescriptionMetadata');
    CalloutStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutStyleUpdatingEventArgsDescriptionMetadata;
})();
